#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-gsk
version:                4.0.8
visibility:             public
id:                     gi-gsk-4.0.8-8VtFPogdW8X1q3O82Kiido
key:                    gi-gsk-4.0.8-8VtFPogdW8X1q3O82Kiido
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               Gsk bindings
description:            Bindings for Gsk, autogenerated by haskell-gi.
category:               Bindings
abi:                    6307ce5bff7015870d40caecca91a010
exposed:                True
exposed-modules:
    GI.Gsk GI.Gsk.Callbacks GI.Gsk.Config GI.Gsk.Enums GI.Gsk.Flags
    GI.Gsk.Functions GI.Gsk.Objects GI.Gsk.Objects.BlendNode
    GI.Gsk.Objects.BlurNode GI.Gsk.Objects.BorderNode
    GI.Gsk.Objects.BroadwayRenderer GI.Gsk.Objects.CairoNode
    GI.Gsk.Objects.CairoRenderer GI.Gsk.Objects.ClipNode
    GI.Gsk.Objects.ColorMatrixNode GI.Gsk.Objects.ColorNode
    GI.Gsk.Objects.ComponentTransferNode
    GI.Gsk.Objects.ConicGradientNode GI.Gsk.Objects.ContainerNode
    GI.Gsk.Objects.CrossFadeNode GI.Gsk.Objects.DebugNode
    GI.Gsk.Objects.FillNode GI.Gsk.Objects.GLRenderer
    GI.Gsk.Objects.GLShader GI.Gsk.Objects.GLShaderNode
    GI.Gsk.Objects.InsetShadowNode GI.Gsk.Objects.LinearGradientNode
    GI.Gsk.Objects.MaskNode GI.Gsk.Objects.NglRenderer
    GI.Gsk.Objects.OpacityNode GI.Gsk.Objects.OutsetShadowNode
    GI.Gsk.Objects.RadialGradientNode GI.Gsk.Objects.RenderNode
    GI.Gsk.Objects.Renderer GI.Gsk.Objects.RepeatNode
    GI.Gsk.Objects.RepeatingLinearGradientNode
    GI.Gsk.Objects.RepeatingRadialGradientNode
    GI.Gsk.Objects.RoundedClipNode GI.Gsk.Objects.ShadowNode
    GI.Gsk.Objects.StrokeNode GI.Gsk.Objects.SubsurfaceNode
    GI.Gsk.Objects.TextNode GI.Gsk.Objects.TextureNode
    GI.Gsk.Objects.TextureScaleNode GI.Gsk.Objects.TransformNode
    GI.Gsk.Objects.VulkanRenderer GI.Gsk.Structs
    GI.Gsk.Structs.ColorStop GI.Gsk.Structs.ComponentTransfer
    GI.Gsk.Structs.ParseLocation GI.Gsk.Structs.Path
    GI.Gsk.Structs.PathBuilder GI.Gsk.Structs.PathMeasure
    GI.Gsk.Structs.PathPoint GI.Gsk.Structs.RoundedRect
    GI.Gsk.Structs.ShaderArgsBuilder GI.Gsk.Structs.Shadow
    GI.Gsk.Structs.Stroke GI.Gsk.Structs.Transform

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-gsk-4.0.8
library-dirs:           /usr/lib/ghc-9.6.6/site-local/gi-gsk-4.0.8 /usr/lib
library-dirs-static:    /usr/lib/ghc-9.6.6/site-local/gi-gsk-4.0.8 /usr/lib
dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-gsk
hs-libraries:           HSgi-gsk-4.0.8-8VtFPogdW8X1q3O82Kiido
extra-libraries:
    gtk-4 pangocairo-1.0 pango-1.0 harfbuzz gdk_pixbuf-2.0
    cairo-gobject cairo vulkan graphene-1.0 gio-2.0 gobject-2.0
    glib-2.0

extra-libraries-static:
    gtk-4 pangocairo-1.0 m pangoft2-1.0 m pango-1.0 m fribidi thai
    datrie Xft harfbuzz-gobject harfbuzz m graphite2 gdk_pixbuf-2.0 m
    glycin-2 seccomp lcms2 m pthread cairo-gobject m dl cairo m dl
    fontconfig m expat m freetype dl bz2 png16 m m brotlidec
    brotlicommon Xext Xrender X11 pthread xcb-render xcb-shm xcb Xau
    Xdmcp pixman-1 m vulkan graphene-1.0 m gio-2.0 gobject-2.0 ffi
    gmodule-2.0 glib-2.0 atomic m pcre2-8 pthread z mount blkid
    sysprof-capture-4

include-dirs:
    /usr/include/gtk-4.0 /usr/include/pango-1.0 /usr/include/fribidi
    /usr/include /usr/include/harfbuzz /usr/include/gdk-pixbuf-2.0
    /usr/include/glycin-2 /usr/include/cairo /usr/include/freetype2
    /usr/include/libpng16 /usr/include/pixman-1
    /usr/include/graphene-1.0 /usr/lib/graphene-1.0/include
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-cairo-1.0.30-LWDjOwc3CRF6YN9VJ5Gx6E
    gi-gdk-4.0.9-Fy3Ki3XXDtrDscJlYvAFVA
    gi-gdkpixbuf-2.0.32-47DylRrxur2AG9bZlPNNF8
    gi-glib-2.0.30-DLGq0zLSPe9IJffMMDar4z
    gi-gobject-2.0.31-BPmt8UFKtJN1IxCDblh8l8
    gi-graphene-1.0.8-DXqVPBa3hc43Q5YEPx53NR
    gi-pango-1.0.30-8W0Qgjy8z0UG8nbB2zWf9y
    haskell-gi-0.26.16-EnHBH4TREzKJyB1oXESazJ
    haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-gsk/html/gi-gsk.haddock
haddock-html:           /usr/share/doc/haskell-gi-gsk/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

